.. _spkg_jsonschema_specifications:

jsonschema_specifications: The JSON Schema meta-schemas and vocabularies, exposed as a Registry
=========================================================================================================

Description
-----------

The JSON Schema meta-schemas and vocabularies, exposed as a Registry

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/jsonschema-specifications/


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_referencing`

Version Information
-------------------

package-version.txt::

    2023.12.1

version_requirements.txt::

    jsonschema-specifications


Equivalent System Packages
--------------------------

(none known)

